Stan Math Library: stan::math::promoter< F, T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::promoter< F, T > Struct Template Reference

`#include <promoter.hpp>`

## Static Public Member Functions
static void | promote (const F &u, T &t)
static T | promote_to (const F &u)

## Detailed Description

### template<typename F, typename T>
struct stan::math::promoter< F, T >

Definition at line 14 of file promoter.hpp.

## Member Function Documentation

template<typename F, typename T>

static void stan::math::promoter< F, T >::promote | ( | const F & | u,
|  | T & | t
| ) |  |
| inlinestatic

Definition at line 15 of file promoter.hpp.

template<typename F, typename T>

static T stan::math::promoter< F, T >::promote_to | ( | const F & | u | ) |
| inlinestatic

Definition at line 18 of file promoter.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/promoter.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.